/*
  Java gfx-test framework

   Copyright (C) 2010, 2011  Red Hat

This file is part of IcedTea.

IcedTea is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 2, or (at your option)
any later version.

IcedTea is distributed in the hope that it will be useful, but
WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
General Public License for more details.

You should have received a copy of the GNU General Public License
along with IcedTea; see the file COPYING.  If not, write to the
Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
02110-1301 USA.

Linking this library statically or dynamically with other modules is
making a combined work based on this library.  Thus, the terms and
conditions of the GNU General Public License cover the whole
combination.

As a special exception, the copyright holders of this library give you
permission to link this library with independent modules to produce an
executable, regardless of the license terms of these independent
modules, and to copy and distribute the resulting executable under
terms of your choice, provided that you also meet, for each linked
independent module, the terms and conditions of the license of that
module.  An independent module is a module which is not derived from
or based on this library.  If you modify this library, you may extend
this exception to your version of the library, but you are not
obligated to do so.  If you do not wish to do so, delete this
exception statement from your version.
*/

package org.gfxtest.testsuites;

import java.awt.Color;
import java.awt.Graphics2D;
import java.awt.MultipleGradientPaint.CycleMethod;



import org.gfxtest.framework.*;
import org.gfxtest.framework.annotations.*;

/**
 * This test renders filled shapes using radial gradient paint.
 *
 * @author Pavel Tisnovsky
 */
@TestType(TestTypes.RENDER_TEST)
@RenderStyle(RenderStyles.FILL)
@Transformation(Transformations.NONE)
@Zoom(1)
public class RadialGradientPaint extends GfxTest
{
    // numbers ranging from 0.0 to 1.0 specifying the distribution of colors along the gradient
    private static final float[] SpectrumFractions = { 0.0f, 1.0f/6, 2.0f/6, 3.0f/6, 4.0f/6, 5.0f/6, 1.0f };

    // array of colors corresponding to each fractional value
    private static final Color[] SpectrumColors = {
        Color.MAGENTA,
        Color.BLUE,
        Color.CYAN,
        Color.GREEN,
        Color.YELLOW,
        Color.ORANGE,
        Color.RED
    };

    /**
     * Test if filled circle drawn by graphics.fillOval() is rendered correctly.
     * Radial gradient paint is used for filling this circle.
     * 
     * @param image
     *            image to which two dimensional shape is to be rendered
     * @param graphics
     *            graphics context for image
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testCircleRadialGradientFill(TestImage image, Graphics2D graphics)
    {
        // set stroke color
        CommonRenderingStyles.setStrokeColor(graphics);
        // set fill color
        CommonRenderingStyles.setRadialGradientFill(image, graphics);
        // draw the circle
        CommonShapesRenderer.drawFilledCircle(image, graphics);
        // test return value
        return TestResult.PASSED;
    }

    /**
     * Test if filled circle drawn by graphics.fillOval() is rendered correctly.
     * Radial Gradient paint is used for filling this circle.
     * 
     * @param image
     *            image to which two dimensional shape is to be rendered
     * @param graphics
     *            graphics context for image
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testCircleRadialGradientFillSmallerRadiusNoCycle(TestImage image, Graphics2D graphics)
    {
        // set stroke color
        CommonRenderingStyles.setStrokeColor(graphics);
        // set fill color
        CommonRenderingStyles.setRadialGradientFill(image, graphics, CycleMethod.NO_CYCLE, 0.5f);
        // draw the circle
        CommonShapesRenderer.drawFilledCircle(image, graphics);
        // test return value
        return TestResult.PASSED;
    }

    /**
     * Test if filled circle drawn by graphics.fillOval() is rendered correctly.
     * Radial Gradient paint is used for filling this circle.
     * 
     * @param image
     *            image to which two dimensional shape is to be rendered
     * @param graphics
     *            graphics context for image
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testCircleRadialGradientFillSmallerRadiusRepeat(TestImage image, Graphics2D graphics)
    {
        // set stroke color
        CommonRenderingStyles.setStrokeColor(graphics);
        // set fill color
        CommonRenderingStyles.setRadialGradientFill(image, graphics, CycleMethod.REPEAT, 0.5f);
        // draw the circle
        CommonShapesRenderer.drawFilledCircle(image, graphics);
        // test return value
        return TestResult.PASSED;
    }

    /**
     * Test if filled circle drawn by graphics.fillOval() is rendered correctly.
     * Radial Gradient paint is used for filling this circle.
     * 
     * @param image
     *            image to which two dimensional shape is to be rendered
     * @param graphics
     *            graphics context for image
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testCircleRadialGradientFillSmallerRadiusReflect(TestImage image, Graphics2D graphics)
    {
        // set stroke color
        CommonRenderingStyles.setStrokeColor(graphics);
        // set fill color
        CommonRenderingStyles.setRadialGradientFill(image, graphics, CycleMethod.REFLECT, 0.5f);
        // draw the circle
        CommonShapesRenderer.drawFilledCircle(image, graphics);
        // test return value
        return TestResult.PASSED;
    }

    /**
     * Test if filled circle drawn by graphics.fillOval() is rendered correctly.
     * Radial Gradient paint is used for filling this circle.
     * 
     * @param image
     *            image to which two dimensional shape is to be rendered
     * @param graphics
     *            graphics context for image
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testCircleRadialGradientFillLargerRadiusNoCycle(TestImage image, Graphics2D graphics)
    {
        // set stroke color
        CommonRenderingStyles.setStrokeColor(graphics);
        // set fill color
        CommonRenderingStyles.setRadialGradientFill(image, graphics, CycleMethod.NO_CYCLE, 2.0f);
        // draw the circle
        CommonShapesRenderer.drawFilledCircle(image, graphics);
        // test return value
        return TestResult.PASSED;
    }

    /**
     * Test if filled circle drawn by graphics.fillOval() is rendered correctly.
     * Radial Gradient paint is used for filling this circle.
     * 
     * @param image
     *            image to which two dimensional shape is to be rendered
     * @param graphics
     *            graphics context for image
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testCircleRadialGradientFillLargerRadiusRepeat(TestImage image, Graphics2D graphics)
    {
        // set stroke color
        CommonRenderingStyles.setStrokeColor(graphics);
        // set fill color
        CommonRenderingStyles.setRadialGradientFill(image, graphics, CycleMethod.REPEAT, 2.0f);
        // draw the circle
        CommonShapesRenderer.drawFilledCircle(image, graphics);
        // test return value
        return TestResult.PASSED;
    }

    /**
     * Test if filled circle drawn by graphics.fillOval() is rendered correctly.
     * Radial Gradient paint is used for filling this circle.
     * 
     * @param image
     *            image to which two dimensional shape is to be rendered
     * @param graphics
     *            graphics context for image
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testCircleRadialGradientFillLargerRadiusReflect(TestImage image, Graphics2D graphics)
    {
        // set stroke color
        CommonRenderingStyles.setStrokeColor(graphics);
        // set fill color
        CommonRenderingStyles.setRadialGradientFill(image, graphics, CycleMethod.REFLECT, 2.0f);
        // draw the circle
        CommonShapesRenderer.drawFilledCircle(image, graphics);
        // test return value
        return TestResult.PASSED;
    }

    /**
     * Test if filled circle drawn by graphics.fillOval() is rendered correctly.
     * Radial Gradient paint is used for filling this circle using whole color
     * spectrum.
     * 
     * @param image
     *            image to which two dimensional shape is to be rendered
     * @param graphics
     *            graphics context for image
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testCircleRadialGradientFillColorSpectrum(TestImage image, Graphics2D graphics)
    {
        // set stroke color
        CommonRenderingStyles.setStrokeColor(graphics);
        // set fill color
        CommonRenderingStyles.setRadialGradientFill(image, graphics, SpectrumFractions, SpectrumColors);
        // draw the circle
        CommonShapesRenderer.drawFilledCircle(image, graphics);
        // test return value
        return TestResult.PASSED;
    }

    /**
     * Test if filled rectangle is rendered correctly.
     * Radial gradient paint is used for filling this rectangle.
     * 
     * @param image
     *            image to which two dimensional shape is to be rendered
     * @param graphics
     *            graphics context for image
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testRectangleRadialGradientFill(TestImage image, Graphics2D graphics)
    {
        // set stroke color
        CommonRenderingStyles.setStrokeColor(graphics);
        // set fill color
        CommonRenderingStyles.setRadialGradientFill(image, graphics);
        // draw the rectangle
        CommonShapesRenderer.drawFilledRectangle(image, graphics);
        // test return value
        return TestResult.PASSED;
    }

    /**
     * Test if filled rectangle is rendered correctly.
     * Radial Gradient paint is used for filling this shape using whole color
     * spectrum.
     * 
     * @param image
     *            image to which two dimensional shape is to be rendered
     * @param graphics
     *            graphics context for image
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testRectangleRadialGradientFillColorSpectrum(TestImage image, Graphics2D graphics)
    {
        // set stroke color
        CommonRenderingStyles.setStrokeColor(graphics);
        // set fill color
        CommonRenderingStyles.setRadialGradientFill(image, graphics, SpectrumFractions, SpectrumColors);
        // draw the rectangle
        CommonShapesRenderer.drawFilledRectangle(image, graphics);
        // test return value
        return TestResult.PASSED;
    }

    /**
     * Test if filled round rectangle is rendered correctly.
     * Radial gradient paint is used for filling this round rectangle.
     * 
     * @param image
     *            image to which two dimensional shape is to be rendered
     * @param graphics
     *            graphics context for image
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testRoundRectangleRadialGradientFill(TestImage image, Graphics2D graphics)
    {
        // set stroke color
        CommonRenderingStyles.setStrokeColor(graphics);
        // set fill color
        CommonRenderingStyles.setRadialGradientFill(image, graphics);
        // draw the round rectangle
        CommonShapesRenderer.drawFilledRoundedRectangle(image, graphics);
        // test return value
        return TestResult.PASSED;
    }

    /**
     * Test if filled round rectangle is rendered correctly.
     * Radial Gradient paint is used for filling this shape using whole color
     * spectrum.
     * 
     * @param image
     *            image to which two dimensional shape is to be rendered
     * @param graphics
     *            graphics context for image
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testRoundRectangleRadialGradientFillColorSpectrum(TestImage image, Graphics2D graphics)
    {
        // set stroke color
        CommonRenderingStyles.setStrokeColor(graphics);
        // set fill color
        CommonRenderingStyles.setRadialGradientFill(image, graphics, SpectrumFractions, SpectrumColors);
        // draw the round rectangle
        CommonShapesRenderer.drawFilledRoundedRectangle(image, graphics);
        // test return value
        return TestResult.PASSED;
    }

    /**
     * Test if filled arc is rendered correctly.
     * Radial gradient paint is used for filling this arc.
     * 
     * @param image
     *            image to which two dimensional shape is to be rendered
     * @param graphics
     *            graphics context for image
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testArcRadialGradientFill(TestImage image, Graphics2D graphics)
    {
        // set stroke color
        CommonRenderingStyles.setStrokeColor(graphics);
        // set fill color
        CommonRenderingStyles.setRadialGradientFill(image, graphics);
        // draw the arc
        CommonShapesRenderer.drawFilledArc(image, graphics);
        // test return value
        return TestResult.PASSED;
    }

    /**
     * Test if filled arc is rendered correctly.
     * Radial Gradient paint is used for filling this shape using whole color
     * spectrum.
     * 
     * @param image
     *            image to which two dimensional shape is to be rendered
     * @param graphics
     *            graphics context for image
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testArcRadialGradientFillColorSpectrum(TestImage image, Graphics2D graphics)
    {
        // set stroke color
        CommonRenderingStyles.setStrokeColor(graphics);
        // set fill color
        CommonRenderingStyles.setRadialGradientFill(image, graphics, SpectrumFractions, SpectrumColors);
        // draw the arc
        CommonShapesRenderer.drawFilledArc(image, graphics);
        // test return value
        return TestResult.PASSED;
    }

    /**
     * Test if filled polygon is rendered correctly.
     * Radial gradient paint is used for filling this polygon.
     * 
     * @param image
     *            image to which two dimensional shape is to be rendered
     * @param graphics
     *            graphics context for image
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testPolygonRadialGradientFill(TestImage image, Graphics2D graphics)
    {
        // set stroke color
        CommonRenderingStyles.setStrokeColor(graphics);
        // set fill color
        CommonRenderingStyles.setRadialGradientFill(image, graphics);
        // draw the polygon
        CommonShapesRenderer.drawFilledPolygon(image, graphics);
        // test return value
        return TestResult.PASSED;
    }

    /**
     * Test if filled polygon is rendered correctly.
     * Radial Gradient paint is used for filling this shape using whole color
     * spectrum.
     * 
     * @param image
     *            image to which two dimensional shape is to be rendered
     * @param graphics
     *            graphics context for image
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testPolygonRadialGradientFillColorSpectrum(TestImage image, Graphics2D graphics)
    {
        // set stroke color
        CommonRenderingStyles.setStrokeColor(graphics);
        // set fill color
        CommonRenderingStyles.setRadialGradientFill(image, graphics, SpectrumFractions, SpectrumColors);
        // draw the polygon
        CommonShapesRenderer.drawFilledPolygon(image, graphics);
        // test return value
        return TestResult.PASSED;
    }

    /**
     * Test if filled closed path is rendered correctly.
     * Radial gradient paint is used for filling this path.
     * 
     * @param image
     *            image to which two dimensional shape is to be rendered
     * @param graphics
     *            graphics context for image
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testClosedPathRadialGradientFill(TestImage image, Graphics2D graphics)
    {
        // set stroke color
        CommonRenderingStyles.setStrokeColor(graphics);
        // set fill color
        CommonRenderingStyles.setRadialGradientFill(image, graphics);
        // draw the closed path
        CommonShapesRenderer.drawFilledClosedPath(image, graphics);
        // test return value
        return TestResult.PASSED;
    }

    /**
     * Test if filled closed path is rendered correctly.
     * Radial Gradient paint is used for filling this shape using whole color
     * spectrum.
     * 
     * @param image
     *            image to which two dimensional shape is to be rendered
     * @param graphics
     *            graphics context for image
     * @return test result status - PASSED, FAILED or ERROR
     */
    public TestResult testClosedPathGradientFillColorSpectrum(TestImage image, Graphics2D graphics)
    {
        // set stroke color
        CommonRenderingStyles.setStrokeColor(graphics);
        // set fill color
        CommonRenderingStyles.setRadialGradientFill(image, graphics, SpectrumFractions, SpectrumColors);
        // draw the closed path
        CommonShapesRenderer.drawFilledClosedPath(image, graphics);
        // test return value
        return TestResult.PASSED;
    }

    /**
     * Entry point to the test suite.
     *
     * @param args graphics test configuration
     */
    public static void main(String[] args)
    {
        new RadialGradientPaint().runTestSuite(args);
    }
}
